[longomatch/newui: 20/157] Rename eventbox widget to something more suitable.



commit bcd81187d08b8a54a11388b1347d10894ac74ff9
Author: Julien Moutte <julien fluendo com>
Date:   Mon Aug 18 19:39:27 2014 +0200

    Rename eventbox widget to something more suitable.

 .../LongoMatch.Gui.Panel.NewProjectPanel.cs        |   19 +++++++++++--------
 .../LongoMatch.Gui.Panel.SportsTemplatesPanel.cs   |   14 +++++++-------
 .../LongoMatch.Gui.Panel.TeamsTemplatesPanel.cs    |   14 +++++++-------
 LongoMatch.GUI/gtk-gui/gui.stetic                  |    8 ++++----
 4 files changed, 29 insertions(+), 26 deletions(-)
---
diff --git a/LongoMatch.GUI/gtk-gui/gui.stetic b/LongoMatch.GUI/gtk-gui/gui.stetic
index 6adb4ca..e0197ce 100644
--- a/LongoMatch.GUI/gtk-gui/gui.stetic
+++ b/LongoMatch.GUI/gtk-gui/gui.stetic
@@ -6280,7 +6280,7 @@ You can continue with the current capture, cancel it or save your project.
       <widget class="Gtk.VBox" id="vbox3">
         <property name="MemberName" />
         <child>
-          <widget class="Gtk.EventBox" id="newheaderbox">
+          <widget class="Gtk.EventBox" id="headereventbox">
             <property name="MemberName" />
             <child>
               <widget class="Gtk.HBox" id="headerhbox">
@@ -7267,7 +7267,7 @@ You can continue with the current capture, cancel it or save your project.
         <property name="MemberName" />
         <property name="Spacing">6</property>
         <child>
-          <widget class="Gtk.EventBox" id="newheaderbox">
+          <widget class="Gtk.EventBox" id="headereventbox">
             <property name="MemberName" />
             <child>
               <widget class="Gtk.HBox" id="headerhbox">
@@ -8939,7 +8939,7 @@ You can continue with the current capture, cancel it or save your project.
         <property name="MemberName" />
         <property name="Spacing">6</property>
         <child>
-          <widget class="Gtk.EventBox" id="newheaderbox">
+          <widget class="Gtk.EventBox" id="headereventbox">
             <property name="MemberName" />
             <child>
               <widget class="Gtk.HBox" id="headerhbox">
@@ -9870,4 +9870,4 @@ You can continue with the current capture, cancel it or save your project.
       </widget>
     </child>
   </widget>
-</stetic-interface>
+</stetic-interface>
\ No newline at end of file


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Panel.NewProjectPanel.cs 
b/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Panel.NewProjectPanel.cs
index 2852ede..13fcfab 100644
--- a/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Panel.NewProjectPanel.cs
+++ b/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Panel.NewProjectPanel.cs
@@ -5,7 +5,7 @@ namespace LongoMatch.Gui.Panel
        public partial class NewProjectPanel
        {
                private global::Gtk.VBox vbox3;
-               private global::Gtk.EventBox newheaderbox;
+               private global::Gtk.EventBox headereventbox;
                private global::Gtk.HBox headerhbox;
                private global::Gtk.Image logoimage;
                private global::Gtk.Label titlelabel;
@@ -84,9 +84,9 @@ namespace LongoMatch.Gui.Panel
                        this.vbox3 = new global::Gtk.VBox ();
                        this.vbox3.Name = "vbox3";
                        // Container child vbox3.Gtk.Box+BoxChild
-                       this.newheaderbox = new global::Gtk.EventBox ();
-                       this.newheaderbox.Name = "newheaderbox";
-                       // Container child newheaderbox.Gtk.Container+ContainerChild
+                       this.headereventbox = new global::Gtk.EventBox ();
+                       this.headereventbox.Name = "headereventbox";
+                       // Container child headereventbox.Gtk.Container+ContainerChild
                        this.headerhbox = new global::Gtk.HBox ();
                        this.headerhbox.Name = "headerhbox";
                        this.headerhbox.Spacing = 6;
@@ -162,9 +162,12 @@ namespace LongoMatch.Gui.Panel
                        w20.Expand = false;
                        // Container child headerhbox.Gtk.Box+BoxChild
                        this.backrectbutton = new global::Gtk.Button ();
+                       this.backrectbutton.WidthRequest = 80;
+                       this.backrectbutton.HeightRequest = 40;
                        this.backrectbutton.CanFocus = true;
                        this.backrectbutton.Name = "backrectbutton";
                        this.backrectbutton.UseUnderline = true;
+                       this.backrectbutton.BorderWidth = ((uint)(10));
                        // Container child backrectbutton.Gtk.Container+ContainerChild
                        global::Gtk.Alignment w21 = new global::Gtk.Alignment (0.5F, 0.5F, 0F, 0F);
                        // Container child GtkAlignment.Gtk.Container+ContainerChild
@@ -185,9 +188,9 @@ namespace LongoMatch.Gui.Panel
                        w29.Position = 4;
                        w29.Expand = false;
                        w29.Fill = false;
-                       this.newheaderbox.Add (this.headerhbox);
-                       this.vbox3.Add (this.newheaderbox);
-                       global::Gtk.Box.BoxChild w31 = ((global::Gtk.Box.BoxChild)(this.vbox3 
[this.newheaderbox]));
+                       this.headereventbox.Add (this.headerhbox);
+                       this.vbox3.Add (this.headereventbox);
+                       global::Gtk.Box.BoxChild w31 = ((global::Gtk.Box.BoxChild)(this.vbox3 
[this.headereventbox]));
                        w31.Position = 0;
                        w31.Expand = false;
                        w31.Fill = false;
@@ -195,7 +198,7 @@ namespace LongoMatch.Gui.Panel
                        this.notebook1 = new global::Gtk.Notebook ();
                        this.notebook1.CanFocus = true;
                        this.notebook1.Name = "notebook1";
-                       this.notebook1.CurrentPage = 0;
+                       this.notebook1.CurrentPage = 1;
                        this.notebook1.ShowBorder = false;
                        this.notebook1.Scrollable = true;
                        // Container child notebook1.Gtk.Notebook+NotebookChild
diff --git a/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Panel.SportsTemplatesPanel.cs 
b/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Panel.SportsTemplatesPanel.cs
index a27aad9..735241a 100644
--- a/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Panel.SportsTemplatesPanel.cs
+++ b/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Panel.SportsTemplatesPanel.cs
@@ -5,7 +5,7 @@ namespace LongoMatch.Gui.Panel
        public partial class SportsTemplatesPanel
        {
                private global::Gtk.VBox vbox3;
-               private global::Gtk.EventBox newheaderbox;
+               private global::Gtk.EventBox headereventbox;
                private global::Gtk.HBox headerhbox;
                private global::Gtk.Image logoimage;
                private global::Gtk.Label titlelabel;
@@ -37,9 +37,9 @@ namespace LongoMatch.Gui.Panel
                        this.vbox3.Name = "vbox3";
                        this.vbox3.Spacing = 6;
                        // Container child vbox3.Gtk.Box+BoxChild
-                       this.newheaderbox = new global::Gtk.EventBox ();
-                       this.newheaderbox.Name = "newheaderbox";
-                       // Container child newheaderbox.Gtk.Container+ContainerChild
+                       this.headereventbox = new global::Gtk.EventBox ();
+                       this.headereventbox.Name = "headereventbox";
+                       // Container child headereventbox.Gtk.Container+ContainerChild
                        this.headerhbox = new global::Gtk.HBox ();
                        this.headerhbox.Name = "headerhbox";
                        this.headerhbox.Spacing = 6;
@@ -90,9 +90,9 @@ namespace LongoMatch.Gui.Panel
                        w11.Position = 2;
                        w11.Expand = false;
                        w11.Fill = false;
-                       this.newheaderbox.Add (this.headerhbox);
-                       this.vbox3.Add (this.newheaderbox);
-                       global::Gtk.Box.BoxChild w13 = ((global::Gtk.Box.BoxChild)(this.vbox3 
[this.newheaderbox]));
+                       this.headereventbox.Add (this.headerhbox);
+                       this.vbox3.Add (this.headereventbox);
+                       global::Gtk.Box.BoxChild w13 = ((global::Gtk.Box.BoxChild)(this.vbox3 
[this.headereventbox]));
                        w13.Position = 0;
                        w13.Expand = false;
                        w13.Fill = false;
diff --git a/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Panel.TeamsTemplatesPanel.cs 
b/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Panel.TeamsTemplatesPanel.cs
index d022913..be31ee9 100644
--- a/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Panel.TeamsTemplatesPanel.cs
+++ b/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Panel.TeamsTemplatesPanel.cs
@@ -5,7 +5,7 @@ namespace LongoMatch.Gui.Panel
        public partial class TeamsTemplatesPanel
        {
                private global::Gtk.VBox vbox3;
-               private global::Gtk.EventBox newheaderbox;
+               private global::Gtk.EventBox headereventbox;
                private global::Gtk.HBox headerhbox;
                private global::Gtk.Image logoimage;
                private global::Gtk.Label titlelabel;
@@ -36,9 +36,9 @@ namespace LongoMatch.Gui.Panel
                        this.vbox3.Name = "vbox3";
                        this.vbox3.Spacing = 6;
                        // Container child vbox3.Gtk.Box+BoxChild
-                       this.newheaderbox = new global::Gtk.EventBox ();
-                       this.newheaderbox.Name = "newheaderbox";
-                       // Container child newheaderbox.Gtk.Container+ContainerChild
+                       this.headereventbox = new global::Gtk.EventBox ();
+                       this.headereventbox.Name = "headereventbox";
+                       // Container child headereventbox.Gtk.Container+ContainerChild
                        this.headerhbox = new global::Gtk.HBox ();
                        this.headerhbox.Name = "headerhbox";
                        this.headerhbox.Spacing = 6;
@@ -89,9 +89,9 @@ namespace LongoMatch.Gui.Panel
                        w11.Position = 2;
                        w11.Expand = false;
                        w11.Fill = false;
-                       this.newheaderbox.Add (this.headerhbox);
-                       this.vbox3.Add (this.newheaderbox);
-                       global::Gtk.Box.BoxChild w13 = ((global::Gtk.Box.BoxChild)(this.vbox3 
[this.newheaderbox]));
+                       this.headereventbox.Add (this.headerhbox);
+                       this.vbox3.Add (this.headereventbox);
+                       global::Gtk.Box.BoxChild w13 = ((global::Gtk.Box.BoxChild)(this.vbox3 
[this.headereventbox]));
                        w13.Position = 0;
                        w13.Expand = false;
                        w13.Fill = false;